@@ -120,7 +120,7 @@ res
 
 
 ###################################################
-### code chunk number 16: graphite.Rnw:241-242
+### code chunk number 16: spia2
 ###################################################
 unlink("keggExSPIA.RData")
 
@@ -139,7 +139,37 @@ runTopologyGSA(p, "var", y1, y2, 0.05)
 
 
 ###################################################
-### code chunk number 18: bldp
+### code chunk number 18: tg2
+###################################################
+library(ALL)
+library(a4Preproc)
+library(clipper)
+
+data(ALL)
+pheno <- as(phenoData(ALL), "data.frame")
+samples <- unlist(lapply(c("NEG", "BCR/ABL"), function(t) {
+  which(grepl("^B\\d*", pheno$BT) & (pheno$mol.biol == t))[1:10]
+}))
+classes <- c(rep(1,10), rep(2,10))
+
+expr <- exprs(ALL)[,samples]
+rownames(expr) <- paste("ENTREZID",
+                        featureData(addGeneInfo(ALL))$ENTREZID,
+                        sep = ":")
+
+k <- as.list(pathways("hsapiens", "kegg"))
+selection <- c("Bladder cancer", "Hippo signaling pathway - multiple species")
+selected <- k[selection]
+names(selected) <- c("Bladder cancer", "Hippo signaling")
+
+clipped <- runClipper(selected, expr, classes, "mean", pathThr = 0.1)
+resClip <- do.call(rbind, clipped$results)
+resClip[, c("startIdx", "endIdx", "maxIdx", "lenght",
+            "maxScore", "aScore")]
+
+
+###################################################
+### code chunk number 19: bldp
 ###################################################
 edges <- data.frame(src_type = "ENTREZID", src="672",
                     dest_type = "ENTREZID", dest="7157",
@@ -149,7 +179,7 @@ pathway <- buildPathway("#1", "example", "hsapiens", "database",
 
 
 ###################################################
-### code chunk number 19: bldp2
+### code chunk number 20: bldp2
 ###################################################
 edges <- data.frame(src_type = "ENTREZID", src="672",
                     dest_type = "ENTREZID", dest="7157",
@@ -167,13 +197,13 @@ pathway <- buildPathway("#1", "example", "hsapiens", "database",
 
 
 ###################################################
-### code chunk number 20: para1 (eval = FALSE)
+### code chunk number 21: para1 (eval = FALSE)
 ###################################################
 ## options(Ncpus = 6)
 
 
 ###################################################
-### code chunk number 21: para2 (eval = FALSE)
+### code chunk number 22: para2 (eval = FALSE)
 ###################################################
 ## original <- pathways("hsapiens", "reactome")
 ## 
@@ -185,7 +215,7 @@ pathway <- buildPathway("#1", "example", "hsapiens", "database",
 
 
 ###################################################
-### code chunk number 22: session
+### code chunk number 23: session
 ###################################################
 sessionInfo()
 
